'use strict'

exports.__esModule = true
exports.Cluster = void 0

var React = /*#__PURE__*/ _interopRequireWildcard(
  /*#__PURE__*/ require('react')
)

var _clsx = /*#__PURE__*/ _interopRequireDefault(/*#__PURE__*/ require('clsx'))

var _Box = /*#__PURE__*/ require('./Box')

var _Layout = /*#__PURE__*/ require('./Layout')

var _styles = /*#__PURE__*/ require('./styles')

function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : {default: obj}
}

function _getRequireWildcardCache() {
  if (typeof WeakMap !== 'function') return null
  var cache = new WeakMap()
  _getRequireWildcardCache = function () {
    return cache
  }
  return cache
}

function _interopRequireWildcard(obj) {
  if (obj && obj.__esModule) {
    return obj
  }
  if (obj === null || (typeof obj !== 'object' && typeof obj !== 'function')) {
    return {default: obj}
  }
  var cache = _getRequireWildcardCache()
  if (cache && cache.has(obj)) {
    return cache.get(obj)
  }
  var newObj = {}
  var hasPropertyDescriptor =
    Object.defineProperty && Object.getOwnPropertyDescriptor
  for (var key in obj) {
    if (Object.prototype.hasOwnProperty.call(obj, key)) {
      var desc = hasPropertyDescriptor
        ? Object.getOwnPropertyDescriptor(obj, key)
        : null
      if (desc && (desc.get || desc.set)) {
        Object.defineProperty(newObj, key, desc)
      } else {
        newObj[key] = obj[key]
      }
    }
  }
  newObj.default = obj
  if (cache) {
    cache.set(obj, newObj)
  }
  return newObj
}

const __reactCreateElement__ = React.createElement

/**
 * A row directional component that distributes its items in a cluster like so:
 *
 * ☐☐☐☐☐
 * ☐☐☐☐☐☐
 * ☐☐☐☐☐
 * ☐☐☐
 *
 * or
 *
 *  ☐☐☐☐☐
 * ☐☐☐☐☐☐
 *  ☐☐☐☐☐
 *    ☐☐☐
 *
 * Some use cases include input chips and tags.
 */
const Cluster = /*#__PURE__*/ React.forwardRef(
  ({className, gap, reverse = false, ...props}, ref) => {
    const {
      styles,
      mq: {prop},
    } = (0, _Layout.useLayout)()
    return /*#__PURE__*/ __reactCreateElement__(_Box.Box, {
      ref: ref,
      className: (0, _clsx.default)(
        className,
        styles.one(`display:flex;flex-wrap:wrap;`)(),
        prop(gapStyle(reverse), gap),
        prop(reverseStyle, reverse)
      ),
      ...props,
    })
  }
)
exports.Cluster = Cluster

const reverseStyle = (reverse) =>
  _styles.flexDirection[reverse ? 'reversedRow' : 'row'] +
  _styles.justifyContent.start

const gapStyle = (reverse) => (gapProp, queryName) => {
  const reversed =
    !reverse || typeof reverse === 'boolean' ? reverse : reverse[queryName]
  const marginDirection = reversed ? 'right' : 'left'
  return ({gap}) =>
    `margin-top:calc(-1 * ${gap[gapProp]})!important;margin-${marginDirection}:calc(-1 * ${gap[gapProp]})!important;&>*{margin-top:${gap[gapProp]}!important;margin-${marginDirection}:${gap[gapProp]}!important;}`
}
